@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2023 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 24
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -16,21 +16,36 @@ from systemID.SystemIDAlgorithms.GetTVMarkovParametersFromTVObserverMarkovParame
 from systemID.SystemIDAlgorithms.GetTVObserverGainMarkovParametersFromTVObserverMarkovParameters import getTVObserverGainMarkovParametersFromTVObserverMarkovParameters
 
 
-def timeVaryingObserverKalmanIdentificationAlgorithmWithObserver(forced_experiments, **kwargs):
+def timeVaryingObserverKalmanIdentificationAlgorithmWithObserver(input_signals, output_signals, **kwargs):
+    """
+    Purpose:
+
+
+    Parameters:
+        -
+
+    Returns:
+        -
+
+    Imports:
+        -
+
+    Description:
+
+
+    See Also:
+        -
+    """
 
     # Dimensions
-    input_dimension = forced_experiments.input_dimension
-    output_dimension = forced_experiments.output_dimension
-    number_steps = forced_experiments.output_signals[0].number_steps
-    number_forced_experiments = forced_experiments.number_experiments
+    input_dimension = input_signals[0].input_dimension
+    output_dimension = output_signals[0].output_dimension
+    number_steps = output_signals[0].number_steps
+    number_forced_experiments = len(output_signals)
 
     # Observer order
     observer_order = kwargs.get("observer_order", number_steps)
 
-    # Inputs and outputs
-    forced_inputs = forced_experiments.input_signals
-    forced_outputs = forced_experiments.output_signals
-
 
     # Time Varying hki_observer1, hki_observer2 and D matrices
     hki_observer1 = np.zeros([(number_steps - 1) * output_dimension, observer_order * input_dimension])
@@ -53,13 +68,14 @@ def timeVaryingObserverKalmanIdentificationAlgorithmWithObserver(forced_experime
 
         # Populate matrices y and V
         for j in range(number_columns_V):
-            y[:, j] = forced_outputs[j].data[:, k]
-            V[0:input_dimension, j] = forced_inputs[j].data[:, k]
+            y[:, j] = output_signals[j].data[:, k]
+            V[0:input_dimension, j] = input_signals[j].data[:, k]
             for i in range(min(observer_order, k)):
-                V[input_dimension + i * (input_dimension + output_dimension):input_dimension + (i + 1) * (input_dimension + output_dimension), j] = np.concatenate((forced_inputs[j].data[:, k - i - 1], forced_outputs[j].data[:, k - i - 1]))
+                V[input_dimension + i * (input_dimension + output_dimension):input_dimension + (i + 1) * (input_dimension + output_dimension), j] = np.concatenate((input_signals[j].data[:, k - i - 1], output_signals[j].data[:, k - i - 1]))
 
         # Least-Squares solution for Observer Markov Parameters
         Mk = np.matmul(y, LA.pinv(V))
+        # print('Error TVOKID', LA.norm(y - np.matmul(Mk, V)))
 
         # Extract Dk
         D[:, :, k] = Mk[:, 0:input_dimension]
@@ -78,7 +94,7 @@ def timeVaryingObserverKalmanIdentificationAlgorithmWithObserver(forced_experime
     # Get TV Observer Gain Markov Parameters from TV Observer Markov Parameters
     hkio = getTVObserverGainMarkovParametersFromTVObserverMarkovParameters(hki_observer2, observer_order)
 
-    return D, hki, hkio
+    return D, hki, hkio, hki_observer1, hki_observer2
 
 
 
